.. include:: ../README.rst

This documentation
------------------

.. toctree::
   :maxdepth: 2
  
   overview
   installation
   upgrade
   configuration
   permissions
   browser
   catalog
   pricing
   discovery
   cmdb
   api
   faq
   changes
   license

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
